from random import choice
from .supportive_functions import (
    generate_female_name,
    generate_male_name,
    remove_duplicates,
)


female_prefix = [
    "ada",
    "al",
    "am",
    "an",
    "bel",
    "beth",
    "ca",
    "ce",
    "cha",
    "da",
    "de",
    "dra",
    "ela",
    "el",
    "ema",
    "en",
    "fa",
    "fay",
    "ga",
    "ge",
    "gi",
    "ha",
    "he",
    "hi",
    "ila",
    "il",
    "ima",
    "in",
    "ja",
    "je",
    "ka",
    "ke",
    "ki",
    "la",
    "le",
    "li",
    "ma",
    "me",
    "mi",
    "na",
    "ne",
    "ni",
    "ola",
    "ol",
    "oma",
    "pa",
    "pe",
    "pi",
    "qua",
    "ra",
    "re",
    "ri",
    "sa",
    "se",
    "sha",
    "ta",
    "te",
    "tha",
    "u",
    "va",
    "ve",
    "vi",
    "wa",
    "we",
    "wi",
    "ya",
    "ye",
    "yi",
    "za",
    "ze",
    "zi",
]

female_suffix = [
    "a",
    "ana",
    "ara",
    "beth",
    "ca",
    "cel",
    "cia",
    "da",
    "dora",
    "e",
    "ella",
    "fa",
    "fay",
    "ga",
    "gine",
    "ha",
    "hilda",
    "ia",
    "ina",
    "ira",
    "la",
    "lina",
    "lissa",
    "ma",
    "mia",
    "na",
    "ne",
    "nia",
    "nissa",
    "ola",
    "ona",
    "ora",
    "pa",
    "pia",
    "ra",
    "ria",
    "rina",
    "sa",
    "sina",
    "sta",
    "ta",
    "tia",
    "trina",
    "va",
    "via",
    "vina",
    "wa",
    "wena",
    "wilda",
    "ya",
    "yna",
    "yra",
    "za",
    "zia",
    "zina",
]

male_prefix = [
    "al",
    "ar",
    "ben",
    "cor",
    "dan",
    "el",
    "fin",
    "gar",
    "hir",
    "ian",
    "jam",
    "kil",
    "lin",
    "mor",
    "nix",
    "or",
    "per",
    "quin",
    "ron",
    "sam",
    "ter",
    "ul",
    "ver",
    "wes",
    "xan",
    "yor",
    "zach",
]

male_suffix = [
    "ald",
    "bert",
    "cor",
    "dard",
    "el",
    "finn",
    "gald",
    "hart",
    "ian",
    "jack",
    "kyle",
    "land",
    "mack",
    "nald",
    "orin",
    "paul",
    "quin",
    "rick",
    "sam",
    "tin",
    "ulph",
    "vald",
    "wick",
    "xander",
    "yor",
    "zeph",
]

female_names = [
    "Alecto",
    "Alice",
    "Alicia",
    "Andromeda",
    "Angelina",
    "Arabella",
    "Ariana",
    "Astoria",
    "Augusta",
    "Aurora",
    "Bellatrix",
    "Bertha",
    "Cassandra",
    "Cedrella",
    "Charity",
    "Cho",
    "Daisy",
    "Demelza",
    "Dolores",
    "Eloise",
    "Fleur",
    "Fridwulfa",
    "Ginny",
    "Hannah",
    "Helena",
    "Helga",
    "Hermione",
    "Lavender",
    "Lily",
    "Luna",
    "Lysandra",
    "Madam",
    "Mafalda",
    "Marietta",
    "Marlene",
    "Merope",
    "Millicent",
    "Minerva",
    "Molly",
    "Morag",
    "Myrtle",
    "Narcissa",
    "Nymphadora",
    "Padma",
    "Pansy",
    "Parvati",
    "Penelope",
    "Petunia",
    "Pomona",
    "Poppy",
    "Rita",
    "Romilda",
    "Rosalind",
    "Rowena",
    "Roxanne",
    "Sybill",
    "Wilhelmina",
]

male_names = [
    "Aberforth",
    "Abraxas",
    "Alastor",
    "Albert",
    "Albus",
    "Amicus",
    "Amos",
    "Amycus",
    "Antonin",
    "Argus",
    "Arthur",
    "Augustus",
    "Avery",
    "Axel",
    "Barnabas",
    "Bartemius",
    "Barty",
    "Basil",
    "Bilius",
    "Bill",
    "Cadmus",
    "Caius",
    "Cassius",
    "Cedric",
    "Charlie",
    "Charlus",
    "Chorley",
    "Colin",
    "Cormac",
    "Cornelius",
    "Damocles",
    "Dawlish",
    "Dean",
    "Dedalus",
    "Dennis",
    "Derek",
    "Devlin",
    "Dexter",
    "Diggle",
    "Dilys",
    "Dimitrov",
    "Dirk",
    "Dobby",
    "Draco",
    "Drystan",
    "Dudley",
    "Elphias",
    "Emeric",
    "Enoch",
    "Ernest",
    "Ernie",
    "Everard",
    "Fabian",
    "Fabius",
    "Falco",
    "Fenrir",
    "Filch",
    "Filius",
    "Finnigan",
    "Fletcher",
    "Flint",
    "Flitwick",
    "Florean",
    "Florian",
    "Florius",
    "Frank",
    "Fred",
    "Fudge",
    "Garrick",
    "Gawain",
    "Gellert",
    "George",
    "Gideon",
    "Gilderoy",
    "Godric",
    "Golpalott",
    "Goyle",
    "Granville",
    "Gregorovitch",
    "Gregory",
    "Griphook",
    "Grogan",
    "Grubbly",
    "Hagrid",
    "Halbert",
    "Hambledon",
    "Hargid",
    "Harkiss",
    "Harry",
    "Hector",
    "Hedwig",
    "Hengist",
    "Hepzibah",
    "Horace",
    "Humphrey",
    "Ignatius",
    "Igor",
    "Isolt",
    "James",
    "John",
    "Justin",
    "Kane",
    "Kingsley",
    "Kirley",
    "Kreacher",
    "Lee",
    "Leopold",
    "Lucius",
    "Ludo",
    "Lupin",
    "Lysander",
    "Marcus",
    "Marius",
    "Michael",
    "Miles",
    "Mondy",
    "Morfin",
    "Mundungus",
    "Myron",
    "Neville",
    "Newt",
    "Nicholas",
    "Nigel",
    "Nott",
    "Oliver",
    "Ollivander",
    "Olympe",
    "Orion",
    "Percy",
    "Peter",
    "Phineas",
    "Piers",
    "Pius",
    "Quirinus",
    "Rab",
    "Rabastan",
    "Ragnok",
    "Ralph",
    "Regulus",
    "Remus",
    "Rodolphus",
    "Roger",
    "Ron",
    "Rubeus",
    "Rufus",
    "Scorpius",
    "Seamus",
    "Septimus",
    "Severus",
    "Sirius",
    "Stan",
    "Sturgis",
    "Ted",
    "Terence",
    "Theodore",
    "Thorfinn",
    "Tiberius",
    "Tom",
    "Ulick",
    "Urquhart",
    "Vernon",
    "Viktor",
    "Vincent",
    "Walden",
    "Westcott",
    "Wilhelm",
    "Wilkie",
    "Winky",
    "Xenophilius",
    "Yaxley",
    "Zacharias",
]

surnames = [
    "Abbott",
    "Abercrombie",
    "Ackerley",
    "Ackerly",
    "Allinson",
    "Almeida",
    "Appleby",
    "Aragon",
    "Archer",
    "Avery",
    "Axminster",
    "Baddock",
    "Bagman",
    "Bagnold",
    "Bagshot",
    "Baron",
    "Baruffio",
    "Basil",
    "Bassat",
    "Beedle",
    "Belby",
    "Bell",
    "Benjy",
    "Bertram",
    "Binns",
    "Black",
    "Blane",
    "Bletchley",
    "Blishwick",
    "Bode",
    "Bones",
    "Boot",
    "Borchart",
    "Bosworth",
    "Branstone",
    "Braveheart",
    "Briar",
    "Bridges",
    "Brocklehurst",
    "Broderick",
    "Brown",
    "Brownstone",
    "Bryce",
    "Bulstrode",
    "Buncle",
    "Burbage",
    "Caddock",
    "Caldwell",
    "Camestros",
    "Campbell",
    "Carneirus",
    "Carrow",
    "Cattermole",
    "Cauldwell",
    "Chadwick",
    "Challenger",
    "Chang",
    "Chapman",
    "Chigley",
    "Chittock",
    "Choudhury",
    "Clagge",
    "Clench",
    "Cobb",
    "Cole",
    "Coleman",
    "Colquhoun",
    "Comstock",
    "Coote",
    "Cornfoot",
    "Crabbe",
    "Cragg",
    "Crane",
    "Creevey",
    "Cresswell",
    "Croaker",
    "Croker",
    "Cross",
    "Crouch",
    "Crowdy",
    "Crup",
    "Dankworth",
    "Dawlish",
    "Dearborn",
    "Delacour",
    "Dell",
    "Diggory",
    "Dippet",
    "Dobbs",
    "Dobson",
    "Docherty",
    "Doge",
    "Dolohov",
    "Dorkins",
    "Dornton",
    "Doyle",
    "Dribble",
    "Droslock",
    "Dudley",
    "Dumbledore",
    "Dunbar",
    "Dungworth",
    "Durant",
    "Dursley",
    "Edgecombe",
    "Edmonds",
    "Edwards",
    "Elder",
    "Elias",
    "Ellis",
    "Elphick",
    "Elphinstone",
    "Everard",
    "Farley",
    "Farthing",
    "Fat",
    "Fawcett",
    "Featherstone",
    "Figg",
    "Filch",
    "Finch",
    "Finch-Fletchley",
    "Finnigan",
    "Firenze",
    "Fisher",
    "Fitz",
    "Fitzroy",
    "Fleet",
    "Flint",
    "Fogarty",
    "Foley",
    "Fonseca",
    "Fontaine",
    "Forbisher",
    "Ford",
    "Fortescue",
    "Foster",
    "Foulkes",
    "Fowler",
    "Foy",
    "Fraser",
    "French",
    "Friar",
    "Frump",
    "Fudge",
    "Fuller",
    "Gaia",
    "Galatea",
    "Gambol",
    "Gamp",
    "Gaunt",
    "Gibbon",
    "Gideon",
    "Gilbert",
    "Gillywater",
    "Glanmore",
    "Glanvill",
    "Gleeson",
    "Glover",
    "Gold",
    "Goldstein",
    "Gonville",
    "Gordon",
    "Gormless",
    "Goshawk",
    "Gossamer",
    "Goudge",
    "Goujon",
    "Goyle",
    "Graham",
    "Granger",
    "Grant",
    "Grantham",
    "Graves",
    "Green",
    "Greengrass",
    "Greenleaf",
    "Greenway",
    "Gregory",
    "Grimblehawk",
    "Grimsditch",
    "Grindelwald",
    "Griselda",
    "Grosswort",
    "Grubbly-Plank",
    "Grunnion",
    "Gudgeon",
    "Gudrun",
    "Gumboil",
    "Gwenog",
    "Hagrid",
    "Halifax",
    "Halstead",
    "Hamilton",
    "Hammerhead",
    "Hampshire",
    "Handy",
    "Hargreaves",
    "Harp",
    "Harper",
    "Harris",
    "Harrow",
    "Hart",
    "Hattersley",
    "Haverstock",
    "Hawthorne",
    "Hayes",
    "Haywood",
    "Hazard",
    "Hecklin",
    "Hedges",
    "Hemming",
    "Hermes",
    "Higglebottom",
    "Higgs",
    "Highfield",
    "Hill",
    "Hillyard",
    "Hodson",
    "Hoggett",
    "Hogwarts",
    "Holborne",
    "Hole",
    "Honey",
    "Hooch",
    "Hookum",
    "Hopkins",
    "Hopkirk",
    "Hoppy",
    "Hornby",
    "Hornung",
    "Horton",
    "Humphrey",
    "Hunt",
    "Hunter",
    "Hutchinson",
    "Huxtable",
    "Ibsen",
    "Ichabod",
    "Impett",
    "Inglebee",
    "Inglethorp",
    "Innes",
    "Intosh",
    "Irons",
    "Isaacs",
    "Ivanova",
    "Ives",
    "Jackman",
    "Jackson",
    "Jacobs",
    "Jaffa",
    "Jenkins",
    "Jenks",
    "Jigger",
    "Johnson",
    "Jolli",
    "Jonas",
    "Jones",
    "Jordan",
    "Jorkins",
    "Juggins",
    "Jugson",
    "Junction",
    "Justice",
    "Jynx",
    "Kaino",
    "Kamkar",
    "Kappa",
    "Karkaroff",
    "Kettleburn",
    "Kidd",
    "Kieron",
    "Killough",
    "King",
    "Kingsley",
    "Kingsnorth",
    "Kirke",
    "Kirkegaard",
    "Kneen",
    "Knibbs",
    "Knott",
    "Knottingley",
    "Knowe",
    "Kramer",
    "Kray",
    "Krum",
    "Krumb",
    "Lacewing",
    "Lackaday",
    "Lancaster",
    "Landsman",
    "Langley",
    "Larkin",
    "LeFevre",
    "Leander",
    "Leek",
    "Leigh",
    "Leitman",
    "Lemon",
    "Lestrange",
    "Levenstein",
    "Levesque",
    "Liddell",
    "Limpet",
    "Littlehales",
    "Lively",
    "Llewellyn",
    "Llewelyn",
    "Lloyd",
    "Lockhart",
    "Lodge",
    "Logan",
    "Long",
    "Longbottom",
    "Longstaff",
    "Lovegood",
    "Lovegrove",
    "Lovett",
    "Lu",
    "Ludovic",
    "Lugwort",
    "Lumby",
    "Lupin",
    "Lupus",
    "Luther",
    "Lynch",
    "Mac",
    "MacAvoy",
    "MacBain",
    "MacBoon",
    "MacCarthy",
    "MacDougal",
    "MacDuff",
    "MacFusty",
    "MacGuffin",
    "MacGuffock",
    "MacHine",
    "MacKinnon",
    "MacKleduff",
    "MacNair",
    "MacNally",
    "MacPherson",
    "MacRory",
    "MacTavish",
    "MacVicar",
    "MacWhirter",
    "Macdonald",
    "Macmillan",
    "Macready",
    "Madam",
    "Madley",
    "Malfoy",
    "Malkin",
    "Mallory",
    "Malone",
    "Mambo",
    "Manco",
    "Manx",
    "March",
    "Marchbanks",
    "Marchmon",
    "Marge",
    "Marples",
    "Mars",
    "Marsh",
    "Marshbanks",
    "Marsland",
    "Martian",
    "Mascarenas",
    "Mason",
    "Maxime",
    "McAllister",
    "McAuley",
    "McBride",
    "McCafferty",
    "McCain",
    "McCann",
    "McClary",
    "McCluck",
    "McCluskey",
    "McCollum",
    "McCorquodale",
    "McCrae",
    "McCullen",
    "McCullough",
    "McDaid",
    "McDermott",
    "McDonald",
    "McDougal",
    "McDowell",
    "McElhinney",
    "McElligott",
    "McEvoy",
    "McFadden",
    "McFarlane",
    "McGarrigle",
    "McGinty",
    "McGonagall",
    "McGrath",
    "McGraw",
    "McGregor",
    "McGuinness",
    "McGuire",
    "McIntosh",
    "McKay",
    "McKechnie",
    "McKendrick",
    "McKenzie",
    "McKeown",
    "McKerrell",
    "McKinney",
    "McLaggen",
    "McLaren",
    "McLaughlin",
    "McLaurin",
    "McLeish",
    "McLeod",
    "McLoughlin",
    "McMackin",
    "McManus",
    "McMaster",
    "McMullan",
    "McMurphy",
    "McMurray",
    "McNab",
    "McNair",
    "McNamara",
    "McNaughton",
    "McNeill",
    "McNulty",
    "McPherson",
    "McQuillan",
    "McQuoid",
    "McRae",
    "McVitie",
    "Meadowes",
    "Meadows",
    "Melling",
    "Mellow",
    "Merrythought",
    "Mertin",
    "Metamorphus",
    "Middleton",
    "Mildew",
    "Mildmay",
    "Millar",
    "Millbank",
    "Milligan",
    "Mills",
    "Milner",
    "Milton",
    "Mintumble",
    "Miserden",
    "Misery",
    "Moffat",
    "Mojo",
    "Monaghan",
    "Moody",
    "Moon",
    "Mooney",
    "Moore",
    "Moran",
    "More",
    "Morgan",
    "Moriarty",
    "Morley",
    "Morlock",
    "Morrow",
    "Mortlake",
    "Mortlock",
    "Morton",
    "Mosby",
    "Moss",
    "Mostafa",
    "Mould",
    "Mouldywart",
    "Mudblood",
    "Muddle",
    "Muff",
    "Muffley",
    "Mulciber",
    "Mullet",
    "Mulready",
    "Mulvihill",
    "Mumbles",
    "Munslow",
    "Munson",
    "Munster",
    "Murdock",
    "Murphy",
    "Mush",
    "Mushy",
    "Musket",
    "Muskett",
    "Mystic",
    "Naggini",
    "Napier",
    "Napper",
    "Narkissos",
    "Nasty",
    "Naylor",
    "Needham",
    "Nellist",
    "Nellson",
    "Nelson",
    "Nelthorpe",
    "Nelwyn",
    "Nervosa",
    "Nettles",
    "Neville",
    "Newberry",
    "Newcomb",
    "Newman",
    "Newt",
    "Nickleby",
    "Niffler",
    "Nigger",
    "Nimrod",
    "Nipper",
    "Nitty",
    "Nixon",
    "Nobble",
    "Nodcock",
    "Noddle",
    "Noddy",
    "Noggin",
    "Nogood",
    "Noidea",
    "Nonsense",
    "Noodle",
    "Nooj",
    "Nook",
    "Nookingham",
    "Nopke",
    "Nork",
    "North",
    "Northbrook",
    "Northend",
    "Northfield",
    "Northman",
    "Norton",
    "Norwood",
    "Nott",
    "Nottley",
    "Novak",
    "Novelty",
    "Nudge",
    "Nugget",
    "Nuisance",
    "Nulbert",
    "Numbus",
    "Nunney",
    "Nutter",
    "Oakey",
    "Oakley",
    "Oblivion",
    "Oblong",
    "Obvious",
    "Ochre",
    "Ogle",
    "Ollerton",
    "Ollivander",
    "Ominous",
    "Onions",
    "Onslaught",
    "Opkirk",
    "Opworthy",
    "Oracle",
    "Orange",
    "Orchard",
    "Orlando",
    "Orton",
    "Orwell",
    "Ossory",
    "Othello",
    "Ott",
    "Otter",
    "Ottery",
    "Otton",
    "Ouldlodge",
    "Ouse",
    "Outhwaite",
    "Outlaw",
    "Outward",
    "Outwhistle",
    "Outwit",
    "Overland",
    "Owen",
    "Owens",
    "Oxford",
    "Oxfordshire",
    "Ozanne",
    "Paddock",
    "Parkinson",
    "Parseltongue",
    "Patil",
    "Peakes",
    "Peasegood",
    "Peebles",
    "Pepper",
    "Perkins",
    "Pettigrew",
    "Peverell",
    "Picquery",
    "Pike",
    "Pince",
    "Pippin",
    "Pirrip",
    "Pius",
    "Plunkett",
    "Podmore",
    "Pomfrey",
    "Ponsonby",
    "Potter",
    "Potts",
    "Poultney",
    "Prewett",
    "Price",
    "Pritchard",
    "Proudfoot",
    "Pruett",
    "Pucey",
    "Puddifoot",
    "Puffett",
    "Pulse",
    "Pye",
    "Quigley",
    "Quirke",
    "Quirrell",
    "Quist",
    "Quong",
    "Rabastan",
    "Radcliffe",
    "Ragnuk",
    "Rappaport",
    "Ravenclaw",
    "Rawle",
    "Reed",
    "Regulus",
    "Reiss",
    "Rellinger",
    "Rennervate",
    "Reynolds",
    "Rhodes",
    "Riddle",
    "Ripper",
    "Robards",
    "Robbins",
    "Roberts",
    "Robinson",
    "Rochfort",
    "Rockwood",
    "Rodriguez",
    "Rolanda",
    "Romilda",
    "Rookwood",
    "Roscoe",
    "Rose",
    "Rosier",
    "Rosmerta",
    "Runcorn",
    "Rusper",
    "Ruthven",
    "Ryan",
    "Ryddle",
    "Ryot",
    "Sabino",
    "Sacharissa",
    "Sagittarius",
    "Salazar",
    "Sallow",
    "Sampson",
    "Sanders",
    "Sanderson",
    "Sansa",
    "Santos",
    "Savage",
    "Saville",
    "Scabior",
    "Scamander",
    "Scarlett",
    "Scorpius",
    "Scrimgeour",
    "Scrimgour",
    "Seamus",
    "Seaton",
    "Selwyn",
    "Severus",
    "Shacklebolt",
    "Shafiq",
    "Shunpike",
    "Sidwell",
    "Sigrid",
    "Silva",
    "Silver",
    "Simms",
    "Sinistra",
    "Skeeter",
    "Skower",
    "Sloper",
    "Slughorn",
    "Slytherin",
    "Smallweed",
    "Smith",
    "Snape",
    "Sneeper",
    "Snyde",
    "Spangle",
    "Sparkle",
    "Sparkman",
    "Spencer",
    "Spinks",
    "Spinnet",
    "Spore",
    "Sprout",
    "Spryly",
    "Stamford",
    "Stanley",
    "Starling",
    "Stebbins",
    "Steele",
    "Stenner",
    "Stepney",
    "Stevens",
    "Stibbons",
    "Stimpson",
    "Stock",
    "Stoog",
    "Stooge",
    "Stooges",
    "Stoogis",
    "Stoogs",
    "Stoogy",
    "Strang",
    "Stratford",
    "Stroud",
    "Strykes",
    "Stump",
    "Sturgis",
    "Sulley",
    "Summers",
    "Sunninghill",
    "Surrey",
    "Sutcliffe",
    "Sutherland",
    "Sweet",
    "Swotter",
    "Sybill",
    "Talbot",
    "Tall",
    "Tamsin",
    "Tankworth",
    "Tarleton",
    "Tassell",
    "Tatting",
    "Tattle",
    "Tawny",
    "Teague",
    "Tempest",
    "Templeton",
    "Tentacula",
    "Terpsichore",
    "Terry",
    "Thicknesse",
    "Thistle",
    "Thomas",
    "Thomson",
    "Thorfinn",
    "Thornton",
    "Thrasher",
    "Threadneedle",
    "Thwaites",
    "Tibbles",
    "Tilcott",
    "Tillerman",
    "Timbers",
    "Timothy",
    "Tirza",
    "Titus",
    "Tofty",
    "Toke",
    "Tolipan",
    "Tonks",
    "Toothill",
    "Topsail",
    "Topsell",
    "Torpel",
    "Travers",
    "Trelawney",
    "Trickett",
    "Trinity",
    "Trionus",
    "Troy",
    "Truffle",
    "Truman",
    "Tuffnell",
    "Tugwood",
    "Tulipan",
    "Tulipan Sr.",
    "Tulipan Sr. Jr.",
    "Turner",
    "Turpin",
    "Twilfitt",
    "Twycross",
    "Umbridge",
    "Upton",
    "Urquhart",
    "Vaisey",
    "Valentine",
    "Vance",
    "Varley",
    "Vasey",
    "Veer",
    "Vekslar",
    "Vernon",
    "Vickers",
    "Vicky",
    "Victoria",
    "Vindictus",
    "Viridian",
    "Volant",
    "Voldemort",
    "Voles",
    "Vonderhaar",
    "Vosper",
    "Wagtail",
    "Walden",
    "Walker",
    "Wallace",
    "Walsingham",
    "Walton",
    "Wang",
    "Warbeck",
    "Ward",
    "Ware",
    "Warren",
    "Warrington",
    "Warwick",
    "Waterson",
    "Watkins",
    "Watson",
    "Weasley",
    "Weatherby",
    "Webber",
    "Webster",
    "Wedge",
    "Weedle",
    "Weedon",
    "Weezy",
    "Welch",
    "Weldon",
    "Wentworth",
    "Wepple",
    "West",
    "Westenberg",
    "Weston",
    "Whalen",
    "Wharton",
    "Wheeler",
    "Whelan",
    "Whipple",
    "Whisper",
    "White",
    "Whitfield",
    "Whitley",
    "Whitney",
    "Whitworth",
    "Whyte",
    "Wilberforce",
    "Wilbur",
    "Wilhelmina",
    "Wilkes",
    "Wilkins",
    "Wilkinson",
    "William",
    "Willis",
    "Willy",
    "Wilpert",
    "Wilson",
    "Wimple",
    "Wimpole",
    "Winchester",
    "Windle",
    "Winston",
    "Winter",
    "Wisteria",
    "Witchwood",
    "Witt",
    "Witterly",
    "Wolfe",
    "Wood",
    "Woodbine",
    "Woodbridge",
    "Woodcroft",
    "Woodruff",
    "Woodville",
    "Woollongong",
    "Wormtail",
    "Wormwood",
    "Worpel",
    "Wright",
    "Wurts",
    "Wycliff",
    "Xenophilius",
    "Yaxley",
    "Yewbeam",
    "York",
    "Yorke",
    "Young",
    "Yule",
    "Zabini",
    "Zacharias",
    "Zambini",
    "Zamojska",
    "Zamojski",
    "Zeller",
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=1)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = choice(surnames)

female_lbr = choice(female_names)
male_lbr = choice(male_names)
